MyTextUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convertToString(
num value, {int decimalPlaces = 2}) → String -
format2String(
String input) → String -
formatNumber(
String number) → String -
formatSeconds(
int seconds) → String -
truncateWithEllipsis(
int cutoff, String myString) → String