MyHomePage class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MyHomePage
- Available extensions
Constructors
- MyHomePage({Key? key, required String title})
-
const
Properties
Methods
-
align(
[AlignmentGeometry alignment = Alignment.center, double? widthFactor, double? heightFactor]) → Widget -
Available on Widget, provided by the CustomWrap extension
-
center(
) → Widget -
Available on Widget, provided by the CustomWrap extension
-
constrained(
{double minWidth = 0.0, double maxWidth = double.infinity, double minHeight = 0.0, double maxHeight = double.infinity}) → Widget -
Available on Widget, provided by the CustomWrap extension
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MyHomePage> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
keepAlive(
) → Widget -
Available on Widget, provided by the CustomWrap extension
-
loc(
List< double?> rect, {double? w, double? h}) → Widget -
Available on Widget, provided by the CustomWrap extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
obx(
) → Widget -
Available on Widget, provided by the CustomWrap extension
-
prop(
{double? width, double? height, List< double> ? margins, List<double> ? paddings, Color? bgColor, String bgUrl = '', List<double> ? borderRadius, double? opacity, double elevation = 0.0, Color shadowColor = const Color(0xFF000000), double? blur, BoxBorder? border, Decoration? decoration, int expanded = 0, bool? gone, bool? hide, dynamic onTap()?, dynamic onLongPress()?, bool clickEffect = true, bool? borderless, double? borderlessSize, bool? rippleInShape, bool hasRoundBg = false}) → Widget -
Available on Widget, provided by the CustomWrap extension
-
safeArea(
) → Widget -
Available on Widget, provided by the CustomWrap extension
-
setStatusBar(
{Color? bgColor, bool iconDark = false}) → Widget -
Available on Widget, provided by the CustomWrap extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited